@@ -14,8 +14,8 @@ from . import recognize
 from . import reorder
 from . import report
 from . import reporttex
+from . import reset
 from . import setup
-from . import setuptex
 from . import stamp
 
 
