@@ -41,6 +41,10 @@ class Sheet(model.buddy.Buddy, metaclass=model.buddy.Register):
     name = 'recognize'
     obj_class = model.sheet.Sheet
 
+    def __init__(self, *args):
+        model.buddy.Buddy.__init__(self, *args)
+        self.filter_image = None
+
     def recognize(self):
         global warned_multipage_not_correctly_scanned
 
@@ -306,6 +310,12 @@ class Sheet(model.buddy.Buddy, metaclass=model.buddy.Register):
 
             i += 2
 
+    def get_page_image(self, page_number):
+        img = self.obj.get_page_image(page_number)
+        if self.filter_image is not None:
+            return img if img == self.filter_image else None
+        return img
+
 
 class Image(model.buddy.Buddy, metaclass=model.buddy.Register):
 
@@ -467,6 +477,13 @@ class Questionnaire(model.buddy.Buddy, metaclass=model.buddy.Register):
         try:
             self.obj.sheet.recognize.recognize()
             result = True
+
+            # Mark sheet as invalid if any page is missing,
+            for page in range(self.obj.page_count):
+                img = self.obj.sheet.get_page_image(page + 1)
+
+                if img is None or img.recognize.matrix is None:
+                    self.obj.sheet.valid = False
         except RecognitionError:
             self.obj.sheet.quality = 0
             result = False
@@ -477,13 +494,26 @@ class Questionnaire(model.buddy.Buddy, metaclass=model.buddy.Register):
 
         return result
 
-    def recognize(self):
+    def recognize(self, skip_identify=False, image=None):
         # recognize image
-        res = self.identify(clean=False)
+        if not skip_identify:
+            assert image is None
+            res = self.identify(clean=False)
+        elif image is None:
+            for img in self.obj.images:
+                if not img.ignored:
+                    img.surface.load()
+            res = True
+        else:
+            image.surface.load()
+            res = True
+
         if res:
             # iterate over qobjects
+            self.obj.sheet.recognize.filter_image = image
             for qobject in self.obj.qobjects:
                 qobject.recognize.recognize()
+            self.obj.sheet.recognize.filter_image = None
 
             quality = 1
             for qobject in self.obj.qobjects:
@@ -546,7 +576,7 @@ class Checkbox(Box, metaclass=model.buddy.Register):
     obj_class = model.questionnaire.Checkbox
 
     def prepare_mask(self):
-        img = self.obj.sheet.get_page_image(self.obj.page_number)
+        img = self.obj.sheet.recognize.get_page_image(self.obj.page_number)
         width, height = self.obj.width, self.obj.height
         line_width = self.obj.lw
 
@@ -625,10 +655,9 @@ class Checkbox(Box, metaclass=model.buddy.Register):
 
 
     def recognize(self):
-        img = self.obj.sheet.get_page_image(self.obj.page_number)
+        img = self.obj.sheet.recognize.get_page_image(self.obj.page_number)
 
         if img is None or img.recognize.matrix is None:
-            self.obj.sheet.valid = 0
             return
 
         surf, xoff, yoff = self.get_outline_mask()
@@ -831,10 +860,9 @@ class Textbox(Box, metaclass=model.buddy.Register):
                     yield x, y
 
         bbox = None
-        img = self.obj.sheet.get_page_image(self.obj.page_number)
+        img = self.obj.sheet.recognize.get_page_image(self.obj.page_number)
 
         if img is None or img.recognize.matrix is None:
-            self.obj.sheet.valid = 0
             return
 
         x = self.obj.x
@@ -899,10 +927,9 @@ class Codebox(Textbox, metaclass=model.buddy.Register):
     obj_class = model.questionnaire.Codebox
 
     def recognize(self):
-        img = self.obj.sheet.get_page_image(self.obj.page_number)
+        img = self.obj.sheet.recognize.get_page_image(self.obj.page_number)
 
         if img is None or img.recognize.matrix is None:
-            self.obj.sheet.valid = 0
             return
 
         x = self.obj.x
